# Field surveys App

We created an interactive web app using `Shiny for Python` to streamline multi-taxon field sampling and data collection. The app enables designing standardized surveys for various organisms like arthropods, birds, and plants.

Accessible on internet-connected devices, it provides a user-friendly interface for field sampling, data storage, and analysis, catering to researchers, citizen scientists, students, and others, regardless of technical expertise or location.

## Set-up your application

Follow the instructions in the [documentation](https://karangattu.github.io/fieldsurveys/) to set up the app for your use case.


## Issues/Feature requests

If you encounter any issues or have any feature requests, please feel free to open an issue on the GitHub repository [here](https://github.com/karangattu/fieldsurveys/issues)